/* $Id: nessus_i18n.h,v 1.1.1.1 2005-09-10 17:36:42 renaud Exp $
 * Copyright (C) 2004 Intevation GmbH
 * Authors:
 * Jan-Oliver Wagner <jan@intevation.de>, Intevation GmbH, 2004
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2,
 * as published by the Free Software Foundation
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef _NESSUSC_NESSUS_I18N_H
#define _NESSUSC_NESSUS_I18N_H

#include <glib/gi18n.h>

#endif /* _NESSUSC_NESSUS_I18N_H */
